==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md <==
---
title: llarp::vpn::LinuxRouteManager

---

# llarp::vpn::LinuxRouteManager





Inherits from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)

## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[LinuxRouteManager](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-linuxroutemanager)**() |
| | **[~LinuxRouteManager](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-~linuxroutemanager)**() |
| virtual void | **[AddRoute](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-addroute)**(IPVariant_t ip, IPVariant_t gateway) override |
| virtual void | **[DelRoute](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-delroute)**(IPVariant_t ip, IPVariant_t gateway) override |
| virtual void | **[AddDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-adddefaultrouteviainterface)**(std::string ifname) override |
| virtual void | **[DelDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-deldefaultrouteviainterface)**(std::string ifname) override |
| virtual void | **[AddRouteViaInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-addrouteviainterface)**([NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn, [IPRange](Classes/structllarp_1_1IPRange.md) range) override |
| virtual void | **[DelRouteViaInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-delrouteviainterface)**([NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn, [IPRange](Classes/structllarp_1_1IPRange.md) range) override |
| virtual std::vector< IPVariant_t > | **[GetGatewaysNotOnInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-getgatewaysnotoninterface)**(std::string ifname) override |
| virtual void | **[AddBlackhole](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-addblackhole)**() override |
| virtual void | **[DelBlackhole](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-delblackhole)**() override |

## Additional inherited members

**Public Types inherited from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)**

|                | Name           |
| -------------- | -------------- |
| using std::variant< [huint32_t](Classes/structllarp_1_1huint__t.md), [huint128_t](Classes/structllarp_1_1huint__t.md) > | **[IPVariant_t](Classes/classllarp_1_1vpn_1_1IRouteManager.md#using-ipvariant-t)**  |

**Public Functions inherited from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)**

|                | Name           |
| -------------- | -------------- |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**() =default |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**(const [IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md) & ) =delete |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**([IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md) && ) =delete |
| virtual | **[~IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-~iroutemanager)**() =default |


## Public Functions Documentation

### function LinuxRouteManager

```cpp
inline LinuxRouteManager()
```


### function ~LinuxRouteManager

```cpp
inline ~LinuxRouteManager()
```


### function AddRoute

```cpp
inline virtual void AddRoute(
    IPVariant_t ip,
    IPVariant_t gateway
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddRoute](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addroute)


### function DelRoute

```cpp
inline virtual void DelRoute(
    IPVariant_t ip,
    IPVariant_t gateway
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelRoute](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delroute)


### function AddDefaultRouteViaInterface

```cpp
inline virtual void AddDefaultRouteViaInterface(
    std::string ifname
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-adddefaultrouteviainterface)


### function DelDefaultRouteViaInterface

```cpp
inline virtual void DelDefaultRouteViaInterface(
    std::string ifname
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-deldefaultrouteviainterface)


### function AddRouteViaInterface

```cpp
inline virtual void AddRouteViaInterface(
    NetworkInterface & vpn,
    IPRange range
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addrouteviainterface)


### function DelRouteViaInterface

```cpp
inline virtual void DelRouteViaInterface(
    NetworkInterface & vpn,
    IPRange range
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delrouteviainterface)


### function GetGatewaysNotOnInterface

```cpp
inline virtual std::vector< IPVariant_t > GetGatewaysNotOnInterface(
    std::string ifname
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::GetGatewaysNotOnInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-getgatewaysnotoninterface)


### function AddBlackhole

```cpp
inline virtual void AddBlackhole() override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddBlackhole](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addblackhole)


### function DelBlackhole

```cpp
inline virtual void DelBlackhole() override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelBlackhole](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delblackhole)


-------------------------------

Updated on 2022-05-31 at 02:25:20 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md <==
---
title: llarp::vpn::LinuxRouteManager

---

# llarp::vpn::LinuxRouteManager





Inherits from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)

## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[LinuxRouteManager](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-linuxroutemanager)**() |
| | **[~LinuxRouteManager](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-~linuxroutemanager)**() |
| virtual void | **[AddRoute](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-addroute)**(net::ipaddr_t ip, net::ipaddr_t gateway) override |
| virtual void | **[DelRoute](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-delroute)**(net::ipaddr_t ip, net::ipaddr_t gateway) override |
| virtual void | **[AddDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-adddefaultrouteviainterface)**([NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn) override |
| virtual void | **[DelDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-deldefaultrouteviainterface)**([NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn) override |
| virtual void | **[AddRouteViaInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-addrouteviainterface)**([NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn, [IPRange](Classes/structllarp_1_1IPRange.md) range) override |
| virtual void | **[DelRouteViaInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-delrouteviainterface)**([NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn, [IPRange](Classes/structllarp_1_1IPRange.md) range) override |
| virtual std::vector< net::ipaddr_t > | **[GetGatewaysNotOnInterface](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-getgatewaysnotoninterface)**([NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md) & vpn) override |
| virtual void | **[AddBlackhole](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-addblackhole)**() override |
| virtual void | **[DelBlackhole](Classes/classllarp_1_1vpn_1_1LinuxRouteManager.md#function-delblackhole)**() override |

## Additional inherited members

**Public Functions inherited from [llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)**

|                | Name           |
| -------------- | -------------- |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**() =default |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**(const [IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md) & ) =delete |
| | **[IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-iroutemanager)**([IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md) && ) =delete |
| virtual | **[~IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-~iroutemanager)**() =default |
| virtual const [llarp::net::Platform](Classes/classllarp_1_1net_1_1Platform.md) * | **[Net_ptr](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-net-ptr)**() const |
| const [llarp::net::Platform](Classes/classllarp_1_1net_1_1Platform.md) & | **[Net](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-net)**() const |


## Public Functions Documentation

### function LinuxRouteManager

```cpp
inline LinuxRouteManager()
```


### function ~LinuxRouteManager

```cpp
inline ~LinuxRouteManager()
```


### function AddRoute

```cpp
inline virtual void AddRoute(
    net::ipaddr_t ip,
    net::ipaddr_t gateway
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddRoute](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addroute)


### function DelRoute

```cpp
inline virtual void DelRoute(
    net::ipaddr_t ip,
    net::ipaddr_t gateway
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelRoute](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delroute)


### function AddDefaultRouteViaInterface

```cpp
inline virtual void AddDefaultRouteViaInterface(
    NetworkInterface & vpn
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-adddefaultrouteviainterface)


### function DelDefaultRouteViaInterface

```cpp
inline virtual void DelDefaultRouteViaInterface(
    NetworkInterface & vpn
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelDefaultRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-deldefaultrouteviainterface)


### function AddRouteViaInterface

```cpp
inline virtual void AddRouteViaInterface(
    NetworkInterface & vpn,
    IPRange range
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addrouteviainterface)


### function DelRouteViaInterface

```cpp
inline virtual void DelRouteViaInterface(
    NetworkInterface & vpn,
    IPRange range
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelRouteViaInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delrouteviainterface)


### function GetGatewaysNotOnInterface

```cpp
inline virtual std::vector< net::ipaddr_t > GetGatewaysNotOnInterface(
    NetworkInterface & vpn
) override
```


**Reimplements**: [llarp::vpn::IRouteManager::GetGatewaysNotOnInterface](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-getgatewaysnotoninterface)


### function AddBlackhole

```cpp
inline virtual void AddBlackhole() override
```


**Reimplements**: [llarp::vpn::IRouteManager::AddBlackhole](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-addblackhole)


### function DelBlackhole

```cpp
inline virtual void DelBlackhole() override
```


**Reimplements**: [llarp::vpn::IRouteManager::DelBlackhole](Classes/classllarp_1_1vpn_1_1IRouteManager.md#function-delblackhole)


-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
